import React, { useState, useRef, useEffect } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import { Card, Row, Col, Space } from 'antd';
import { useIntl } from 'umi';
import {
  getSummary2,
  getAreaTotalOrg,
  getDeviceTotalOrg,
  getAreaTotalPerson,
  getDeviceTotalPerson,
} from '@/services/welcome';
import WCard from './components/WelcomeCard';
import Bar from './components/Bar/index.jsx';
import BarPerson from './components/BarPerson/index.jsx';
import TownBar from './components/TownBar';
import './Welcome.less';

const Welcome = () => {
  const intl = useIntl();
  const [topData, setTopData] = useState([]);

  const [categoryData, setCategoryData] = useState([]);
  const [lineData, setLineData] = useState([]);
  const [personData, setPersonData] = useState([]);
  const [persondData, setPersDonData] = useState([]);

  // 卡片展示
  useEffect(() => {
    getSummary2().then((res) => {
      const data = res.map((it) => {
        return {
          title:
            it.name == 'person'
              ? '人员'
              : it.name == 'org'
              ? '合作社'
              : it.name == 'device'
              ? '设备'
              : '作业',
          value:
            it.name == 'person'
              ? it.value + '个'
              : it.name == 'org'
              ? it.value + '个'
              : it.name == 'device'
              ? it.value + '台'
              : it.value + '亩',
          icon:
            it.name == 'person'
              ? 'icon-icon'
              : it.name == 'org'
              ? 'icon-show_gongsiguanli_fill'
              : it.name == 'device'
              ? 'icon-tuolaji'
              : 'icon-dingdanguanli',
          color:
            it.name == 'person'
              ? '#1cbbb4'
              : it.name == 'org'
              ? '#8dc63f'
              : it.name == 'device'
              ? '#a5673f'
              : '#8799a3',
        };
      });
      setTopData(data);
    });
  }, []);
  // 柱状图展示亩
  useEffect(() => {
    getAreaTotalOrg().then((res) => {
      setCategoryData(res);
    });
  }, []);

  // 柱状图展示设备
  useEffect(() => {
    getDeviceTotalOrg().then((res) => {
      setLineData(res);
    });
  }, []);

  // 柱状图 人员作业统计

  useEffect(() => {
    getAreaTotalPerson().then((res) => {
      setPersonData(res);
    });
  }, []);

  // 柱状图 人员设备统计

  useEffect(() => {
    getDeviceTotalPerson().then((res) => {
      setPersDonData(res);
    });
  }, []);

  return (
    <PageContainer>
      <div className="welcome">
        <div className="head">
          <Row justify="space-between">
            <Col flex="1">
              <WCard value={topData[0]} />
            </Col>
            <Col flex="1" style={{ marginLeft: '24px' }}>
              <WCard value={topData[1]} />
            </Col>
            <Col flex="1" style={{ marginLeft: '24px' }}>
              <WCard value={topData[2]} />
            </Col>
            <Col flex="1" style={{ marginLeft: '24px' }}>
              <WCard value={topData[3]} />
            </Col>
          </Row>
        </div>
        <Card title="各乡镇数据统计" style={{ marginTop: '24px' }}>
          <TownBar height="500px" />
        </Card>
        <Card title="合作社数据统计" style={{ marginTop: '24px' }}>
          <Bar height="500px" opt={categoryData} optL={lineData} />
        </Card>
        <Card title="人员数据统计" style={{ marginTop: '24px' }}>
          <BarPerson height="500px" opt={personData} optP={persondData} />
        </Card>
      </div>
    </PageContainer>
  );
};

export default Welcome;
